==> zio-aws-athena_3-5.17.155.2-sources.jar: zio/aws/athena/model/ResultConfiguration.scala <==
package zio.aws.athena.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ResultConfiguration(
    outputLocation: Option[String] = None,
    encryptionConfiguration: Option[
      zio.aws.athena.model.EncryptionConfiguration
    ] = None,
    expectedBucketOwner: Option[String] = None,
    aclConfiguration: Option[zio.aws.athena.model.AclConfiguration] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.ResultConfiguration = {
    import ResultConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.ResultConfiguration
      .builder()
      .optionallyWith(outputLocation.map(value => value: java.lang.String))(
        _.outputLocation
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(
        expectedBucketOwner.map(value => value: java.lang.String)
      )(_.expectedBucketOwner)
      .optionallyWith(aclConfiguration.map(value => value.buildAwsValue()))(
        _.aclConfiguration
      )
      .build()
  }
  def asReadOnly: zio.aws.athena.model.ResultConfiguration.ReadOnly =
    zio.aws.athena.model.ResultConfiguration.wrap(buildAwsValue())
}
object ResultConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.ResultConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.ResultConfiguration =
      zio.aws.athena.model.ResultConfiguration(
        outputLocation.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        expectedBucketOwner.map(value => value),
        aclConfiguration.map(value => value.asEditable)
      )
    def outputLocation: Option[String]
    def encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly]
    def expectedBucketOwner: Option[String]
    def aclConfiguration: Option[zio.aws.athena.model.AclConfiguration.ReadOnly]
    def getOutputLocation: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("outputLocation", outputLocation)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.athena.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getExpectedBucketOwner: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
    def getAclConfiguration
        : ZIO[Any, AwsError, zio.aws.athena.model.AclConfiguration.ReadOnly] =
      AwsError.unwrapOptionField("aclConfiguration", aclConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ) extends zio.aws.athena.model.ResultConfiguration.ReadOnly {
    override val outputLocation: Option[String] =
      scala.Option(impl.outputLocation()).map(value => value: String)
    override val encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly] = scala
      .Option(impl.encryptionConfiguration())
      .map(value => zio.aws.athena.model.EncryptionConfiguration.wrap(value))
    override val expectedBucketOwner: Option[String] =
      scala.Option(impl.expectedBucketOwner()).map(value => value: String)
    override val aclConfiguration
        : Option[zio.aws.athena.model.AclConfiguration.ReadOnly] = scala
      .Option(impl.aclConfiguration())
      .map(value => zio.aws.athena.model.AclConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ): zio.aws.athena.model.ResultConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-athena_3-5.17.178.1-sources.jar: zio/aws/athena/model/ResultConfiguration.scala <==
package zio.aws.athena.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ResultConfiguration(
    outputLocation: Optional[String] = Optional.Absent,
    encryptionConfiguration: Optional[
      zio.aws.athena.model.EncryptionConfiguration
    ] = Optional.Absent,
    expectedBucketOwner: Optional[String] = Optional.Absent,
    aclConfiguration: Optional[zio.aws.athena.model.AclConfiguration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.ResultConfiguration = {
    import ResultConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.ResultConfiguration
      .builder()
      .optionallyWith(outputLocation.map(value => value: java.lang.String))(
        _.outputLocation
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(
        expectedBucketOwner.map(value => value: java.lang.String)
      )(_.expectedBucketOwner)
      .optionallyWith(aclConfiguration.map(value => value.buildAwsValue()))(
        _.aclConfiguration
      )
      .build()
  }
  def asReadOnly: zio.aws.athena.model.ResultConfiguration.ReadOnly =
    zio.aws.athena.model.ResultConfiguration.wrap(buildAwsValue())
}
object ResultConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.ResultConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.ResultConfiguration =
      zio.aws.athena.model.ResultConfiguration(
        outputLocation.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        expectedBucketOwner.map(value => value),
        aclConfiguration.map(value => value.asEditable)
      )
    def outputLocation: Optional[String]
    def encryptionConfiguration
        : Optional[zio.aws.athena.model.EncryptionConfiguration.ReadOnly]
    def expectedBucketOwner: Optional[String]
    def aclConfiguration
        : Optional[zio.aws.athena.model.AclConfiguration.ReadOnly]
    def getOutputLocation: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("outputLocation", outputLocation)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.athena.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getExpectedBucketOwner: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
    def getAclConfiguration
        : ZIO[Any, AwsError, zio.aws.athena.model.AclConfiguration.ReadOnly] =
      AwsError.unwrapOptionField("aclConfiguration", aclConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ) extends zio.aws.athena.model.ResultConfiguration.ReadOnly {
    override val outputLocation: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.outputLocation())
      .map(value => value: String)
    override val encryptionConfiguration
        : Optional[zio.aws.athena.model.EncryptionConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionConfiguration())
        .map(value => zio.aws.athena.model.EncryptionConfiguration.wrap(value))
    override val expectedBucketOwner: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.expectedBucketOwner())
      .map(value => value: String)
    override val aclConfiguration
        : Optional[zio.aws.athena.model.AclConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.aclConfiguration())
        .map(value => zio.aws.athena.model.AclConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ): zio.aws.athena.model.ResultConfiguration.ReadOnly = new Wrapper(impl)
}
